@@ -32,35 +32,46 @@ import qubesadmin.exc
 import qubesadmin.vm
 from qubesadmin.utils import parse_size
 
-from ..widgets.gtk_widgets import VMListModeler, \
-    TextModeler, TraitSelector, NONE_CATEGORY
+from ..widgets.gtk_widgets import (
+    VMListModeler,
+    TextModeler,
+    TraitSelector,
+    NONE_CATEGORY,
+)
 from .page_handler import PageHandler
-from ..widgets.utils import get_feature, get_boolean_feature, \
-    apply_feature_change
+from ..widgets.utils import (
+    get_feature,
+    get_boolean_feature,
+    apply_feature_change,
+)
 
 import gi
 
-gi.require_version('Gtk', '3.0')
+gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
 
-logger = logging.getLogger('qubes-global-config')
+logger = logging.getLogger("qubes-global-config")
 
 import gettext
+
 t = gettext.translation("desktop-linux-manager", fallback=True)
 _ = t.gettext
 
+
 class KernelVersion:  # pylint: disable=too-few-public-methods
     """Helper class to be used in sorting kernels. Cannot use
     distutils.version.LooseVersion, because it fails at handling
     versions that have no numbers in them, which is quite possible with
     custom kernels."""
+
     def __init__(self, string):
         self.string = string
-        self.groups = re.compile(r'(\d+)').split(self.string)
+        self.groups = re.compile(r"(\d+)").split(self.string)
 
     def __lt__(self, other):
-        for (self_content, other_content) in itertools.zip_longest(
-                self.groups, other.groups):
+        for self_content, other_content in itertools.zip_longest(
+            self.groups, other.groups
+        ):
             if self_content == other_content:
                 continue
             if self_content is None:
@@ -74,6 +85,7 @@ class KernelVersion:  # pylint: disable=too-few-public-methods
 
 class AbstractTraitHolder(abc.ABC):
     """Handler for all sorts of widgets reflecting system traits."""
+
     @abc.abstractmethod
     def get_model(self) -> TraitSelector:
         """Get the TraitSelector for current Trait."""
@@ -113,11 +125,17 @@ class AbstractTraitHolder(abc.ABC):
 
 class PropertyHandler(AbstractTraitHolder):
     """Handles comboboxes reflecting for object properties."""
-    def __init__(self, qapp: qubesadmin.Qubes, trait_holder: Any,
-                 trait_name: str, widget: Gtk.ComboBox,
-                 vm_filter: Optional[Callable] = None,
-                 readable_name: Optional[str] = None,
-                 additional_options: Optional[Dict[str, str]] = None):
+
+    def __init__(
+        self,
+        qapp: qubesadmin.Qubes,
+        trait_holder: Any,
+        trait_name: str,
+        widget: Gtk.ComboBox,
+        vm_filter: Optional[Callable] = None,
+        readable_name: Optional[str] = None,
+        additional_options: Optional[Dict[str, str]] = None,
+    ):
         self.qapp = qapp
         self.trait_holder = trait_holder
         self.trait_name = trait_name
@@ -130,7 +148,7 @@ class PropertyHandler(AbstractTraitHolder):
             filter_function=vm_filter,
             current_value=self.get_current_value(),
             style_changes=True,
-            additional_options=additional_options
+            additional_options=additional_options,
         )
 
     def get_readable_description(self) -> str:
@@ -144,15 +162,22 @@ class PropertyHandler(AbstractTraitHolder):
             new_value = self.model.get_selected()
             setattr(self.trait_holder, self.trait_name, new_value)
 
-    def get_model(self) -> TraitSelector:
+    def get_model(self) -> VMListModeler:
         return self.model
 
 
 class FeatureHandler(AbstractTraitHolder):
     """Handles comboboxes reflecting vm features."""
-    def __init__(self, trait_holder: Any, trait_name: str,
-                 widget: Gtk.ComboBoxText, options: Dict[str, Any],
-                 readable_name: str, is_bool: bool = False):
+
+    def __init__(
+        self,
+        trait_holder: Any,
+        trait_name: str,
+        widget: Gtk.ComboBoxText,
+        options: Dict[str, Any],
+        readable_name: str,
+        is_bool: bool = False,
+    ):
         self.trait_holder = trait_holder
         self.trait_name = trait_name
         self.widget = widget
@@ -161,8 +186,10 @@ class FeatureHandler(AbstractTraitHolder):
 
         self.model = TextModeler(
             combobox=self.widget,
-            values=options, selected_value=self.get_current_value(),
-            style_changes=True)
+            values=options,
+            selected_value=self.get_current_value(),
+            style_changes=True,
+        )
 
     def get_readable_description(self) -> str:
         return self.readable_name
@@ -180,29 +207,199 @@ class FeatureHandler(AbstractTraitHolder):
     def get_model(self) -> TraitSelector:
         return self.model
 
+
+class PreloadDispvmHandler(AbstractTraitHolder):
+    """Handler for preloaded disposables. Requires SpinButton widgets:
+    'basics_preload_dispvm'"""
+
+    def __init__(
+        self,
+        qapp: qubesadmin.Qubes,
+        gtk_builder: Gtk.Builder,
+        defdispvm_model: VMListModeler,
+    ):
+        self.qapp = qapp
+        self.defdispvm_model = defdispvm_model
+        self.preload_dispvm_spin: Gtk.SpinButton = gtk_builder.get_object(
+            "basics_preload_dispvm"
+        )
+        self.preload_dispvm_threshold_spin: Gtk.SpinButton = gtk_builder.get_object(
+            "basics_preload_dispvm_threshold"
+        )
+        self.preload_dispvm_check: Gtk.CheckButton = gtk_builder.get_object(
+            "basics_preload_dispvm_check"
+        )
+
+        self.defdispvm_model.connect_change_callback(self.on_defdispvm_changed)
+        self.preload_dispvm_check.connect("toggled", self.on_check_changed)
+
+        self.default_max = 1
+        self.preload_dispvm_spin.props.numeric = True
+        self.preload_dispvm_spin_adjustment = Gtk.Adjustment()
+        self.preload_dispvm_spin_adjustment.configure(0, 0, 9999, 1, 5, 0)
+        self.preload_dispvm_spin.configure(self.preload_dispvm_spin_adjustment, 0.1, 0)
+
+        self.preload_dispvm_threshold_spin.props.numeric = True
+        self.preload_dispvm_threshold_spin_adjustment = Gtk.Adjustment()
+        self.preload_dispvm_threshold_spin_adjustment.configure(
+            0, 0, 999999, 100, 1000, 0
+        )
+        self.preload_dispvm_threshold_spin.configure(
+            self.preload_dispvm_threshold_spin_adjustment, 0.1, 0
+        )
+
+        self.on_defdispvm_changed()
+        self.on_check_changed()
+        self.initial_preload_dispvm_spin_sensitive = (
+            self.preload_dispvm_spin.is_sensitive()
+        )
+        self.preload_dispvm_threshold_spin.set_value(self.get_current_threshold_value())
+
+    def on_defdispvm_changed(self):
+        defdispvm = self.defdispvm_model.get_selected()
+        if defdispvm:
+            self.preload_dispvm_check.set_sensitive(True)
+            self.preload_dispvm_check.set_active(self.get_feat_value() is not None)
+        else:
+            self.preload_dispvm_check.set_sensitive(False)
+            self.preload_dispvm_check.set_active(False)
+
+    def on_check_changed(self, *args):  # pylint: disable=unused-argument
+        defdispvm = self.defdispvm_model.get_selected()
+        preloadcheck = self.preload_dispvm_check.get_active()
+        if defdispvm and preloadcheck:
+            if self.get_feat_value() is None:
+                value = self.default_max
+            else:
+                value = self.get_current_value()
+            self.preload_dispvm_spin.set_value(value)
+            self.preload_dispvm_spin.set_sensitive(True)
+        else:
+            self.preload_dispvm_spin.set_value(0)
+            self.preload_dispvm_spin.set_sensitive(False)
+
+    @staticmethod
+    def get_readable_description() -> str:  # pylint: disable=arguments-differ
+        """Get human-readable description of the widget"""
+        # the pylint: disable above is because pylint does not understand
+        # static methods
+        return _("Number of preloaded disposables from default dispvm")
+
+    def get_feat_value(self):
+        """Get current system value as is"""
+        return get_feature(self.qapp.domains["dom0"], "preload-dispvm-max")
+
+    def get_feat_threshold_value(self):
+        """Get current system threshold value as is"""
+        return get_feature(self.qapp.domains["dom0"], "preload-dispvm-threshold")
+
+    def get_current_value(self):
+        """Get current system value of the handled feature"""
+        return int(self.get_feat_value() or 0)
+
+    def get_current_threshold_value(self):
+        """Get current system value of the handled feature"""
+        return int(self.get_feat_threshold_value() or 0)
+
+    def is_max_changed(self) -> bool:
+        """Has the user selected something different from the initial value?"""
+        if (
+            self.initial_preload_dispvm_spin_sensitive
+            != self.preload_dispvm_spin.is_sensitive()
+        ):
+            return True
+        if self.preload_dispvm_spin.get_value_as_int() != self.get_current_value():
+            return True
+        return False
+
+    def is_threshold_changed(self) -> bool:
+        """Has the user selected something different from the initial value?"""
+        return (
+            self.preload_dispvm_threshold_spin.get_value_as_int()
+            != self.get_current_threshold_value()
+        )
+
+    def is_changed(self) -> bool:
+        """Has the user selected something different from the initial value?"""
+        if self.is_max_changed() or self.is_threshold_changed():
+            return True
+        return False
+
+    def get_unsaved(self):
+        """Get human-readable description of unsaved changes, or
+        empty string if none were found."""
+        if self.is_changed():
+            return self.get_readable_description()
+        return ""
+
+    def save(self):
+        """Save changes: update system value and mark it as new initial value"""
+        if not self.is_changed():
+            return
+
+        if self.is_threshold_changed():
+            threshold_value = str(self.preload_dispvm_threshold_spin.get_value_as_int())
+            apply_feature_change(
+                self.qapp.domains["dom0"],
+                "preload-dispvm-threshold",
+                threshold_value,
+            )
+
+        # Every other feature must be set before "max" (prior to preload routine).
+        if self.is_max_changed():
+            if self.preload_dispvm_spin.is_sensitive():
+                value = str(self.preload_dispvm_spin.get_value_as_int())
+            else:
+                value = None
+            apply_feature_change(
+                self.qapp.domains["dom0"],
+                "preload-dispvm-max",
+                value,
+            )
+            if value is None:
+                self.initial_preload_dispvm_spin_sensitive = False
+            else:
+                self.initial_preload_dispvm_spin_sensitive = True
+
+    def reset(self):
+        """Reset selection to the initial value."""
+        if self.preload_dispvm_spin.is_sensitive():
+            self.preload_dispvm_spin.set_value(self.get_current_value())
+        if self.preload_dispvm_threshold_spin.is_sensitive():
+            self.preload_dispvm_threshold_spin.set_value(
+                self.get_current_threshold_value()
+            )
+
+    def update_current_value(self):
+        """This should never be called."""
+        raise NotImplementedError
+
+    def get_model(self) -> TraitSelector:
+        """This should never be called."""
+        raise NotImplementedError
+
+
 class QMemManHelper:
     """Helper class to handle the ugliness of managing qmemman config."""
-    QMEMMAN_CONFIG_PATH = '/etc/qubes/qmemman.conf'
-    MINMEM_NAME = 'vm-min-mem'
-    DOM0_NAME = 'dom0-mem-boost'
+
+    QMEMMAN_CONFIG_PATH = "/etc/qubes/qmemman.conf"
+    MINMEM_NAME = "vm-min-mem"
+    DOM0_NAME = "dom0-mem-boost"
 
     def __init__(self):
         self.qmemman_config = None
 
     def get_values(self) -> Dict[str, int]:
         """Returns a dict of 'vm-min-mem': value in MiB and
-        'dom0-mem-boost': value in MiB """
+        'dom0-mem-boost': value in MiB"""
         self.qmemman_config = ConfigParser()
         self.qmemman_config.read(self.QMEMMAN_CONFIG_PATH)
 
-        result = {
-            self.MINMEM_NAME: 200,
-            self.DOM0_NAME: 350
-        }
+        result = {self.MINMEM_NAME: 200, self.DOM0_NAME: 350}
 
-        if self.qmemman_config.has_section('global'):
+        if self.qmemman_config.has_section("global"):
             for key in result:
-                str_value = self.qmemman_config.get('global', key)
+                str_value = self.qmemman_config.get("global", key)
                 value = parse_size(str_value)
                 result[key] = int(value / 1024 / 1024)
 
@@ -212,11 +409,13 @@ class QMemManHelper:
         """Wants a dict of 'vm-min-mem': value in MiB and
         'dom0-mem-boost': value in MiB"""
         # qmemman settings
-        text_dict = {key: str(int(value)) + 'MiB'
-                     for key, value in values_dict.items()}
+        text_dict = {key: str(int(value)) + "MiB" for key, value in values_dict.items()}
 
-        assert len(text_dict) == 2 and \
-               self.MINMEM_NAME in text_dict and self.DOM0_NAME in text_dict
+        assert (
+            len(text_dict) == 2
+            and self.MINMEM_NAME in text_dict
+            and self.DOM0_NAME in text_dict
+        )
 
         # reinitialize the ConfigParser object, because it is somewhat
         # unhappy to handle multiple consecutive writes and reads
@@ -224,27 +423,26 @@ class QMemManHelper:
         self.qmemman_config = ConfigParser()
         self.qmemman_config.read(self.QMEMMAN_CONFIG_PATH)
 
-        if not self.qmemman_config.has_section('global'):
+        if not self.qmemman_config.has_section("global"):
             # add the whole section
-            self.qmemman_config.add_section('global')
+            self.qmemman_config.add_section("global")
             for key in text_dict:
-                self.qmemman_config.set(
-                    'global', key, text_dict[key])
-            self.qmemman_config.set(
-                'global', 'cache-margin-factor', str(1.3))
+                self.qmemman_config.set("global", key, text_dict[key])
+            self.qmemman_config.set("global", "cache-margin-factor", str(1.3))
 
-            with open(self.QMEMMAN_CONFIG_PATH, 'a') as qmemman_config_file:
+            with open(self.QMEMMAN_CONFIG_PATH, "a") as qmemman_config_file:
                 self.qmemman_config.write(qmemman_config_file)
 
         else:
             # If there already is a 'global' section, we don't use
             # SafeConfigParser.write() - it would get rid of
             # all the comments...
-            lines_to_add = {key: f'{key} = {value}\n'
-                            for key, value in text_dict.items()}
+            lines_to_add = {
+                key: f"{key} = {value}\n" for key, value in text_dict.items()
+            }
 
             config_lines = []
-            with open(self.QMEMMAN_CONFIG_PATH, 'r') as qmemman_config_file:
+            with open(self.QMEMMAN_CONFIG_PATH, "r") as qmemman_config_file:
                 for line in qmemman_config_file:
                     for key in lines_to_add:
                         if line.strip().startswith(key):
@@ -257,18 +455,21 @@ class QMemManHelper:
             for line in lines_to_add:
                 config_lines.append(line)
 
-            with open(self.QMEMMAN_CONFIG_PATH, 'w') as qmemman_config_file:
+            with open(self.QMEMMAN_CONFIG_PATH, "w") as qmemman_config_file:
                 qmemman_config_file.writelines(config_lines)
 
 
 class MemoryHandler(AbstractTraitHolder):
     """Handler for memory / QMemMan settings. Requires SpinButton widgets:
     'basics_min_memory' and 'basics_dom0_memory'"""
+
     def __init__(self, gtk_builder):
-        self.min_memory_spin: Gtk.SpinButton = \
-            gtk_builder.get_object('basics_min_memory')
-        self.dom0_memory_spin: Gtk.SpinButton = \
-            gtk_builder.get_object('basics_dom0_memory')
+        self.min_memory_spin: Gtk.SpinButton = gtk_builder.get_object(
+            "basics_min_memory"
+        )
+        self.dom0_memory_spin: Gtk.SpinButton = gtk_builder.get_object(
+            "basics_dom0_memory"
+        )
 
         self.min_memory_adjustment = Gtk.Adjustment()
         self.min_memory_adjustment.configure(0, 0, 999999, 1, 10, 0)
@@ -288,9 +489,11 @@ class MemoryHandler(AbstractTraitHolder):
             self.dom0_memory_spin.set_sensitive(False)
 
         self.min_memory_spin.set_value(
-            self.initial_values.get(self.mem_helper.MINMEM_NAME, 0))
+            self.initial_values.get(self.mem_helper.MINMEM_NAME, 0)
+        )
         self.dom0_memory_spin.set_value(
-            self.initial_values.get(self.mem_helper.DOM0_NAME, 0))
+            self.initial_values.get(self.mem_helper.DOM0_NAME, 0)
+        )
 
     @staticmethod
     def get_readable_description() -> str:  # pylint: disable=arguments-differ
@@ -306,7 +509,7 @@ class MemoryHandler(AbstractTraitHolder):
 
         values = {
             self.mem_helper.MINMEM_NAME: int(self.min_memory_spin.get_value()),
-            self.mem_helper.DOM0_NAME: int(self.dom0_memory_spin.get_value())
+            self.mem_helper.DOM0_NAME: int(self.dom0_memory_spin.get_value()),
         }
 
         self.mem_helper.save_values(values)
@@ -316,21 +519,27 @@ class MemoryHandler(AbstractTraitHolder):
         if not self.min_memory_spin.is_sensitive():
             return
 
-        self.min_memory_spin.set_value(self.initial_values.get(
-            self.mem_helper.MINMEM_NAME, 0))
-        self.dom0_memory_spin.set_value(self.initial_values.get(
-            self.mem_helper.DOM0_NAME, 0))
+        self.min_memory_spin.set_value(
+            self.initial_values.get(self.mem_helper.MINMEM_NAME, 0)
+        )
+        self.dom0_memory_spin.set_value(
+            self.initial_values.get(self.mem_helper.DOM0_NAME, 0)
+        )
 
     def is_changed(self) -> bool:
         """Has the user selected something different from the initial value?"""
-        if not self.min_memory_spin.is_sensitive() or \
-                not self.dom0_memory_spin.is_sensitive():
+        if (
+            not self.min_memory_spin.is_sensitive()
+            or not self.dom0_memory_spin.is_sensitive()
+        ):
             return False
         if self.min_memory_spin.get_value() != self.initial_values.get(
-            self.mem_helper.MINMEM_NAME, 0):
+            self.mem_helper.MINMEM_NAME, 0
+        ):
             return True
         if self.dom0_memory_spin.get_value() != self.initial_values.get(
-            self.mem_helper.DOM0_NAME, 0):
+            self.mem_helper.DOM0_NAME, 0
+        ):
             return True
         return False
 
@@ -356,6 +565,7 @@ class MemoryHandler(AbstractTraitHolder):
 
 class KernelHolder(AbstractTraitHolder):
     """Trait holder for list of available Linux kernels"""
+
     def __init__(self, qapp: qubesadmin.Qubes, widget: Gtk.ComboBoxText):
         self.qapp = qapp
         self.widget = widget
@@ -364,15 +574,14 @@ class KernelHolder(AbstractTraitHolder):
             combobox=self.widget,
             values=self._get_kernel_options(),
             selected_value=self.get_current_value(),
-            style_changes=True
+            style_changes=True,
         )
 
     def _get_kernel_options(self) -> Dict[str, str]:
-        kernels = [kernel.vid for kernel in
-                   self.qapp.pools['linux-kernel'].volumes]
+        kernels = [kernel.vid for kernel in self.qapp.pools["linux-kernel"].volumes]
         kernels = sorted(kernels, key=KernelVersion)
         kernels_dict = {kernel: kernel for kernel in kernels}
-        kernels_dict['(none)'] = None
+        kernels_dict["(none)"] = None
         return kernels_dict
 
     def get_readable_description(self) -> str:
@@ -393,6 +602,7 @@ class BasicSettingsHandler(PageHandler):
     """
     Handler for the Basic Settings page.
     """
+
     def __init__(self, gtk_builder: Gtk.Builder, qapp: qubesadmin.Qubes):
         """
         :param gtk_builder: gtk_builder object
@@ -403,85 +613,146 @@ class BasicSettingsHandler(PageHandler):
 
         self.handlers: List[AbstractTraitHolder] = []
 
-        self.clockvm_combo = gtk_builder.get_object('basics_clockvm_combo')
-        self.deftemplate_combo: Gtk.ComboBox = \
-            gtk_builder.get_object('basics_deftemplate_combo')
-        self.defnetvm_combo: Gtk.ComboBox = \
-            gtk_builder.get_object('basics_defnetvm_combo')
-        self.defdispvm_combo: Gtk.ComboBox = \
-            gtk_builder.get_object('basics_defdispvm_combo')
-        self.fullscreen_combo: Gtk.ComboBoxText = \
-            gtk_builder.get_object('basics_fullscreen_combo')
-        self.utf_combo: Gtk.ComboBoxText = \
-            gtk_builder.get_object('basics_utf_windows_combo')
-        self.tray_icon_combo: Gtk.ComboBoxText = \
-            gtk_builder.get_object('basics_tray_icon_combo')
-        self.kernel_combo: Gtk.ComboBoxText = \
-            gtk_builder.get_object('basics_kernel_combo')
+        self.clockvm_combo = gtk_builder.get_object("basics_clockvm_combo")
+        self.deftemplate_combo: Gtk.ComboBox = gtk_builder.get_object(
+            "basics_deftemplate_combo"
+        )
+        self.defnetvm_combo: Gtk.ComboBox = gtk_builder.get_object(
+            "basics_defnetvm_combo"
+        )
+        self.defdispvm_combo: Gtk.ComboBox = gtk_builder.get_object(
+            "basics_defdispvm_combo"
+        )
+        self.fullscreen_combo: Gtk.ComboBoxText = gtk_builder.get_object(
+            "basics_fullscreen_combo"
+        )
+        self.utf_combo: Gtk.ComboBoxText = gtk_builder.get_object(
+            "basics_utf_windows_combo"
+        )
+        self.tray_icon_combo: Gtk.ComboBoxText = gtk_builder.get_object(
+            "basics_tray_icon_combo"
+        )
+        self.kernel_combo: Gtk.ComboBoxText = gtk_builder.get_object(
+            "basics_kernel_combo"
+        )
 
-        self.handlers.append(PropertyHandler(
-            qapp=self.qapp, trait_holder=self.qapp, trait_name="clockvm",
-            widget=self.clockvm_combo, vm_filter=self._clock_vm_filter,
-            readable_name=_("Clock qube"), additional_options=NONE_CATEGORY))
-        self.handlers.append(PropertyHandler(
-            qapp=self.qapp, trait_holder=self.qapp,
-            trait_name="default_template", widget=self.deftemplate_combo,
-            vm_filter=self._default_template_filter,
-            readable_name=_("Default template"),
-            additional_options=NONE_CATEGORY))
-        self.handlers.append(PropertyHandler(
-            qapp=self.qapp, trait_holder=self.qapp, trait_name="default_netvm",
-            widget=self.defnetvm_combo, vm_filter=self._default_netvm_filter,
-            readable_name=_("Default net qube"),
-            additional_options=NONE_CATEGORY))
-        self.handlers.append(PropertyHandler(
-            qapp=self.qapp, trait_holder=self.qapp, trait_name="default_dispvm",
-            widget=self.defdispvm_combo, vm_filter=self._default_dispvm_filter,
-            readable_name=_("Default disposable qube template"),
-            additional_options=NONE_CATEGORY))
-        self.handlers.append(FeatureHandler(
-            trait_holder=self.vm, trait_name='gui-default-allow-fullscreen',
-            widget=self.fullscreen_combo,
-            options={_('default (disallow)'): None, _('allow'): True,
-                     _('disallow'): False},
-            readable_name=_("Allow fullscreen"), is_bool=True))
-        self.handlers.append(FeatureHandler(
-            trait_holder=self.vm, trait_name='gui-default-allow-utf8-titles',
-            widget=self.utf_combo,
-            options={_('default (disallow)'): None, _('allow'): True,
-                     _('disallow'): False},
-            readable_name=_("Allow utf8 window titles"), is_bool=True))
-        self.handlers.append(FeatureHandler(
-            trait_holder=self.vm, trait_name='gui-default-trayicon-mode',
-            widget=self.tray_icon_combo,
-            options={_('default (tinted icon)'): None,
-             _('full background'): 'bg',
-             _('thin border'): 'border1',
-             _('thick border'): 'border2',
-             _('tinted icon'): 'tint',
-             _('tinted icon with modified white'): 'tint+whitehack',
-             _('tinted icon with 50% saturation'): 'tint+saturation50'},
-            readable_name="Tray icon mode", is_bool=False))
-        self.handlers.append(KernelHolder(qapp=self.qapp,
-                                          widget=self.kernel_combo))
+        self.handlers.append(
+            PropertyHandler(
+                qapp=self.qapp,
+                trait_holder=self.qapp,
+                trait_name="clockvm",
+                widget=self.clockvm_combo,
+                vm_filter=self._clock_vm_filter,
+                readable_name=_("Clock qube"),
+                additional_options=NONE_CATEGORY,
+            )
+        )
+        self.handlers.append(
+            PropertyHandler(
+                qapp=self.qapp,
+                trait_holder=self.qapp,
+                trait_name="default_template",
+                widget=self.deftemplate_combo,
+                vm_filter=self._default_template_filter,
+                readable_name=_("Default template"),
+                additional_options=NONE_CATEGORY,
+            )
+        )
+        self.handlers.append(
+            PropertyHandler(
+                qapp=self.qapp,
+                trait_holder=self.qapp,
+                trait_name="default_netvm",
+                widget=self.defnetvm_combo,
+                vm_filter=self._default_netvm_filter,
+                readable_name=_("Default net qube"),
+                additional_options=NONE_CATEGORY,
+            )
+        )
+        self.handlers.append(
+            PropertyHandler(
+                qapp=self.qapp,
+                trait_holder=self.qapp,
+                trait_name="default_dispvm",
+                widget=self.defdispvm_combo,
+                vm_filter=self._default_dispvm_filter,
+                readable_name=_("Default disposable qube template"),
+                additional_options=NONE_CATEGORY,
+            )
+        )
+        defdispvm_model: VMListModeler = self.handlers[-1].get_model()  # type: ignore
+        self.handlers.append(
+            PreloadDispvmHandler(
+                qapp=self.qapp,
+                gtk_builder=gtk_builder,
+                defdispvm_model=defdispvm_model,
+            )
+        )
+        self.handlers.append(
+            FeatureHandler(
+                trait_holder=self.vm,
+                trait_name="gui-default-allow-fullscreen",
+                widget=self.fullscreen_combo,
+                options={
+                    _("default (disallow)"): None,
+                    _("allow"): True,
+                    _("disallow"): False,
+                },
+                readable_name=_("Allow fullscreen"),
+                is_bool=True,
+            )
+        )
+        self.handlers.append(
+            FeatureHandler(
+                trait_holder=self.vm,
+                trait_name="gui-default-allow-utf8-titles",
+                widget=self.utf_combo,
+                options={
+                    _("default (disallow)"): None,
+                    _("allow"): True,
+                    _("disallow"): False,
+                },
+                readable_name=_("Allow utf8 window titles"),
+                is_bool=True,
+            )
+        )
+        self.handlers.append(
+            FeatureHandler(
+                trait_holder=self.vm,
+                trait_name="gui-default-trayicon-mode",
+                widget=self.tray_icon_combo,
+                options={
+                    _("default (tinted icon)"): None,
+                    _("full background"): "bg",
+                    _("thin border"): "border1",
+                    _("thick border"): "border2",
+                    _("tinted icon"): "tint",
+                    _("tinted icon with modified white"): "tint+whitehack",
+                    _("tinted icon with 50% saturation"): "tint+saturation50",
+                },
+                readable_name="Tray icon mode",
+                is_bool=False,
+            )
+        )
+        self.handlers.append(KernelHolder(qapp=self.qapp, widget=self.kernel_combo))
 
         self.handlers.append(MemoryHandler(gtk_builder))
 
     @staticmethod
     def _clock_vm_filter(vm) -> bool:
-        return vm.klass != 'TemplateVM'
+        return vm.klass != "TemplateVM"
 
     @staticmethod
     def _default_template_filter(vm) -> bool:
-        return vm.klass == 'TemplateVM'
+        return vm.klass == "TemplateVM"
 
     @staticmethod
     def _default_netvm_filter(vm) -> bool:
-        return getattr(vm, 'provides_network', False)
+        return getattr(vm, "provides_network", False)
 
     @staticmethod
     def _default_dispvm_filter(vm) -> bool:
-        return getattr(vm, 'template_for_dispvms', False)
+        return getattr(vm, "template_for_dispvms", False)
 
     def save(self):
         for handler in self.handlers:
